@@ -38,6 +38,18 @@
   (add-hook 'mime-setup-load-hook
 	    '(lambda () (load "rail-user-agent"))))
 
+(and (fboundp 'eval-after-load)
+     (eval-after-load "mime-play"
+       (progn
+	 (load "rail-mime-example-1-13")
+	 '(rail-mime-example-1-13-setup))))
+
+(and (fboundp 'eval-after-load)
+     (eval-after-load "mime-view"
+       (progn
+	 (load "rail-mime-example-1-14")
+	 '(rail-mime-example-1-14-setup))))
+
 (require 'rail-pj)
 
 (provide 'rail)
